@@ -1,6 +1,6 @@
 package Net::Stripe;
 use Moose;
-use MooseX::Method::Signatures;
+use Kavorka;
 use LWP::UserAgent;
 use HTTP::Request::Common qw/GET POST DELETE/;
 use MIME::Base64 qw/encode_base64/;
@@ -706,7 +706,7 @@ Net::Stripe - API client for Stripe.com
 
 =head1 VERSION
 
-version 0.15
+version 0.16
 
 =head1 SYNOPSIS
 
